@@ -1,8 +1,7 @@
 requirejs.config({
     paths: {
-        /* Load cogram from local server. On fail, load from CDN. */
+        /* Load cogram from CDN. */
         'cogram': [
-            '//localhost:8080/cogramStatic/cogram_main',
             '//storage.googleapis.com/cogram-public/jupyter-cogram/latest/cogram_main.min',
         ],
     },
